All Classes and Interfaces
Class
Description
Helper class that provides a MethodHandles.Lookup that allows defining classes in this package.
Classloader used to run the core agent.
A stand-in for the bootstrap class loader.
Agent start up logic.
BootstrapPackagePrefixesHolder is an utility class that holds package prefixes.Helper class for
ClassLoader.defineClass callbacks.Context returned from
beforeDefineClass and passed to afterDefineClass.Class used for exception handler logging.
Helper class that provides a MethodHandles.Lookup that allows defining classes in this package.
A holder of resources needed by instrumentation.
Contains the bootstrap method for initializing invokedynamic callsites which are added via agent
instrumentation.
Helper class for detecting and loading injected helper classes.
This class serves as an "everywhere accessible" source of
Instrumentation instance.Interface added to indy proxies to allow unwrapping the proxy object
This class serves as an "everywhere accessible" source of the agent jar file.
Helper class that provides a MethodHandles.Lookup that allows defining classes in this package.
Helper class that provides a MethodHandles.Lookup that allows defining classes in this package.
Transformer for lambda bytecode
Holder for
LambdaTransformer used by the instrumentation.Premain-Class for the OpenTelemetry Java agent.
A helper to facilitate accessing OpenTelemetry SDK methods from instrumentation.
Interface matching
io.opentelemetry.sdk.trace.SdkTracerProvider#forceFlush() to allow
holding a reference to it.Dependencies of the agent sometimes call java.util.logging.Logger.getLogger().
Helper class that provides a MethodHandles.Lookup that allows defining classes in this package.
A marker interface implemented by virtual field accessor classes.
Helper class for detecting whether given class has virtual fields.
A marker interface that signifies that virtual fields have been installed into the class that
implements it.
Helper class that provides a MethodHandles.Lookup that allows defining classes in this package.