Class HelperResources
java.lang.Object
io.opentelemetry.javaagent.bootstrap.HelperResources
A holder of resources needed by instrumentation. We store them in the bootstrap class loader so
instrumentation can store from the agent class loader and apps can retrieve from the app class
loader.
-
Method Summary
Modifier and TypeMethodDescriptionloadAll(ClassLoader classLoader, String path) Returns allURLs that can be used to retrieve the content of the resource atpath.static URLloadOne(ClassLoader classLoader, String path) Returns aURLthat can be used to retrieve the content of the resource atpath, ornullif no resource could be found atpath.static voidregister(ClassLoader classLoader, String path, List<URL> urls) Registers theurlsto be available to instrumentation atpath, when givenclassLoaderattempts to load that resource.static voidregisterForAllClassLoaders(String path, List<URL> urls) Registers theurlsto be available to instrumentation atpath.
-
Method Details
-
register
Registers theurlsto be available to instrumentation atpath, when givenclassLoaderattempts to load that resource. -
registerForAllClassLoaders
Registers theurlsto be available to instrumentation atpath. -
loadOne
Returns aURLthat can be used to retrieve the content of the resource atpath, ornullif no resource could be found atpath. -
loadAll
Returns allURLs that can be used to retrieve the content of the resource atpath.
-