Class IndyBootstrapDispatcher
java.lang.Object
io.opentelemetry.javaagent.bootstrap.IndyBootstrapDispatcher
Contains the bootstrap method for initializing invokedynamic callsites which are added via agent
instrumentation.
-
Method Summary
Modifier and TypeMethodDescriptionstatic CallSitebootstrap(MethodHandles.Lookup lookup, String adviceMethodName, MethodType adviceMethodType, Object... args) static MethodHandlegenerateNoopMethodHandle(MethodType methodType) static voidinit(MethodHandle bootstrapMethod) Initialized the invokedynamic bootstrapping method to which this class will delegate.
-
Method Details
-
init
Initialized the invokedynamic bootstrapping method to which this class will delegate.- Parameters:
bootstrapMethod- the method to delegate to. Must have the same type asbootstrap.
-
bootstrap
public static CallSite bootstrap(MethodHandles.Lookup lookup, String adviceMethodName, MethodType adviceMethodType, Object... args) -
generateNoopMethodHandle
-