Package io.opentelemetry.javaagent.bootstrap
package io.opentelemetry.javaagent.bootstrap
-
ClassDescriptionClassloader used to run the core agent.A stand-in for the bootstrap class loader.Agent start up logic.
BootstrapPackagePrefixesHolderis an utility class that holds package prefixes.Helper class forClassLoader.defineClasscallbacks.Context returned frombeforeDefineClassand passed toafterDefineClass.Class used for exception handler logging.A holder of resources needed by instrumentation.Contains the bootstrap method for initializing invokedynamic callsites which are added via agent instrumentation.Helper class for detecting and loading injected helper classes.This class serves as an "everywhere accessible" source ofInstrumentationinstance.This class serves as an "everywhere accessible" source of the agent jar file.Transformer for lambda bytecodeHolder forLambdaTransformerused by the instrumentation.A helper to facilitate accessing OpenTelemetry SDK methods from instrumentation.Interface matchingio.opentelemetry.sdk.trace.SdkTracerProvider#forceFlush()to allow holding a reference to it.Dependencies of the agent sometimes call java.util.logging.Logger.getLogger().